"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePicker = void 0;
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importStar(require("react"));
var utils_1 = require("./utils");
var formatters_1 = require("./formatters");
var constants_1 = require("./constants");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var tinycolor = require("tinycolor2");
var squareSize = constants_1.config.squareSize, crossSize = constants_1.config.crossSize;
var PickerContext = (0, react_1.createContext)();
function PickerContextWrapper(_a) {
    var children = _a.children, bounds = _a.bounds, value = _a.value, onChange = _a.onChange;
    var offsetLeft = bounds === null || bounds === void 0 ? void 0 : bounds.x;
    var isGradient = value === null || value === void 0 ? void 0 : value.includes('gradient');
    var gradientType = (0, utils_1.getGradientType)(value);
    var degrees = (0, utils_1.getDegrees)(value);
    var degreeStr = gradientType === 'linear-gradient' ? "".concat(degrees, "deg") : 'circle';
    var colors = (0, formatters_1.getColors)(value);
    var indexedColors = colors === null || colors === void 0 ? void 0 : colors.map(function (c, i) { return (tslib_1.__assign(tslib_1.__assign({}, c), { index: i })); });
    var currentColorObj = (indexedColors === null || indexedColors === void 0 ? void 0 : indexedColors.filter(function (c) { return (0, utils_1.isUpperCase)(c.value); })[0]) || indexedColors[0];
    var currentColor = currentColorObj === null || currentColorObj === void 0 ? void 0 : currentColorObj.value;
    var selectedColor = currentColorObj === null || currentColorObj === void 0 ? void 0 : currentColorObj.index;
    var currentLeft = currentColorObj === null || currentColorObj === void 0 ? void 0 : currentColorObj.left;
    var _b = (0, react_1.useState)(tinycolor(currentColor)), tinyColor = _b[0], setTinyColor = _b[1];
    var _c = (0, react_1.useState)('rgb'), inputType = _c[0], setInputType = _c[1];
    var _d = tinyColor.toRgb(), r = _d.r, g = _d.g, b = _d.b, opacity = _d.a;
    var _e = tinyColor.toHsl(), h = _e.h, s = _e.s, l = _e.l;
    var _f = tinyColor.toHsv(), hsvS = _f.s, hsvV = _f.v;
    var _g = (0, react_1.useState)(Math.round(h)), internalHue = _g[0], setInternalHue = _g[1];
    var hue = Math.round(h);
    var _h = (0, utils_1.computeSquareXY)([hue, s, l]), x = _h[0], y = _h[1];
    var _j = (0, react_1.useState)([]), previousColors = _j[0], setPreviousColors = _j[1];
    var _k = (0, react_1.useState)([]), previousGraidents = _k[0], setPreviousGradients = _k[1];
    (0, react_1.useEffect)(function () {
        setTinyColor(tinycolor(currentColor));
        setInternalHue(hue);
    }, [currentColor, hue]);
    (0, react_1.useEffect)(function () {
        if (isGradient) {
            setPreviousGradients(tslib_1.__spreadArray([value], previousGraidents === null || previousGraidents === void 0 ? void 0 : previousGraidents.slice(0, 4), true));
        }
        else {
            if (tinycolor(value).isValid()) {
                setPreviousColors(tslib_1.__spreadArray([value], previousColors === null || previousColors === void 0 ? void 0 : previousColors.slice(0, 4), true));
            }
        }
        //eslint-disable-next-line
    }, [value]);
    var createGradientStr = function (newColors) {
        var sorted = newColors.sort(function (a, b) { return a.left - b.left; });
        var colorString = sorted === null || sorted === void 0 ? void 0 : sorted.map(function (cc) { return "".concat(cc === null || cc === void 0 ? void 0 : cc.value, " ").concat(cc.left, "%"); });
        onChange("".concat(gradientType, "(").concat(degreeStr, ", ").concat(colorString.join(', '), ")"));
    };
    var handleGradient = function (newColor, left) {
        if (left === void 0) { left = currentLeft; }
        var remaining = colors === null || colors === void 0 ? void 0 : colors.filter(function (c) { return !(0, utils_1.isUpperCase)(c.value); });
        var newColors = tslib_1.__spreadArray([{ value: newColor.toUpperCase(), left: left }], remaining, true);
        createGradientStr(newColors);
    };
    var handleChange = function (newColor) {
        if (isGradient) {
            handleGradient(newColor);
        }
        else {
            onChange(newColor);
        }
    };
    var handleOpacity = function (e) {
        var newO = (0, utils_1.getHandleValue)(e) / 100;
        var newColor = "rgba(".concat(r, ", ").concat(g, ", ").concat(b, ", ").concat(newO, ")");
        handleChange(newColor);
    };
    var handleHue = function (e) {
        var newHue = (0, utils_1.getHandleValue)(e) * 3.6;
        var newHsl = (0, utils_1.getNewHsl)(newHue, s, l, opacity, setInternalHue);
        handleChange(newHsl);
    };
    var handleColor = function (e, ctx) {
        var _a = (0, utils_1.computePickerPosition)(e), x = _a[0], y = _a[1];
        var x1 = Math.min(x + crossSize / 2, squareSize - 1);
        var y1 = Math.min(y + crossSize / 2, squareSize - 1);
        var _b = ctx.getImageData(x1, y1, 1, 1).data, r = _b[0], g = _b[1], b = _b[2];
        var newColor = "rgba(".concat(r, ", ").concat(g, ", ").concat(b, ", ").concat(opacity, ")");
        handleChange(newColor);
    };
    var setSelectedColor = function (index) {
        var newGradStr = colors === null || colors === void 0 ? void 0 : colors.map(function (cc, i) { return (tslib_1.__assign(tslib_1.__assign({}, cc), { value: i === index ? (0, formatters_1.high)(cc) : (0, formatters_1.low)(cc) })); });
        createGradientStr(newGradStr);
    };
    var addPoint = function (e) {
        var left = (0, utils_1.getHandleValue)(e, offsetLeft);
        var newColors = tslib_1.__spreadArray(tslib_1.__spreadArray([], colors.map(function (c) { return (tslib_1.__assign(tslib_1.__assign({}, c), { value: (0, formatters_1.low)(c) })); }), true), [{ value: currentColor, left: left }], false);
        createGradientStr(newColors);
    };
    var deletePoint = function () {
        if ((colors === null || colors === void 0 ? void 0 : colors.length) > 2) {
            var remaining = colors === null || colors === void 0 ? void 0 : colors.filter(function (rc, i) { return i !== selectedColor; });
            createGradientStr(remaining);
        }
    };
    var pickerState = {
        x: x,
        y: y,
        s: s,
        l: l,
        r: r,
        g: g,
        b: b,
        hue: hue,
        hsvS: hsvS,
        hsvV: hsvV,
        value: value,
        colors: colors,
        degrees: degrees,
        opacity: opacity,
        onChange: onChange,
        addPoint: addPoint,
        inputType: inputType,
        tinyColor: tinyColor,
        handleHue: handleHue,
        isGradient: isGradient,
        offsetLeft: offsetLeft,
        handleColor: handleColor,
        currentLeft: currentLeft,
        deletePoint: deletePoint,
        internalHue: internalHue,
        setInputType: setInputType,
        gradientType: gradientType,
        handleChange: handleChange,
        currentColor: currentColor,
        selectedColor: selectedColor,
        handleOpacity: handleOpacity,
        setInternalHue: setInternalHue,
        previousColors: previousColors,
        handleGradient: handleGradient,
        setSelectedColor: setSelectedColor,
        previousGraidents: previousGraidents,
    };
    return react_1.default.createElement(PickerContext.Provider, { value: pickerState }, children);
}
exports.default = PickerContextWrapper;
function usePicker() {
    return (0, react_1.useContext)(PickerContext);
}
exports.usePicker = usePicker;
PickerContextWrapper.propTypes = {
    children: prop_types_1.default.node,
    bounds: prop_types_1.default.object,
    value: prop_types_1.default.string,
    onChange: prop_types_1.default.func,
};
//# sourceMappingURL=context.js.map