"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isUpperCase = exports.safeBounds = exports.getNewHsl = exports.getGradientType = exports.getDegrees = exports.computePickerPosition = exports.computeSquareXY = exports.getHandleValue = void 0;
var formatters_1 = require("./formatters");
var constants_1 = require("./constants");
var tc = require("tinycolor2");
var squareSize = constants_1.config.squareSize, barSize = constants_1.config.barSize, crossSize = constants_1.config.crossSize;
function getHandleValue(e) {
    var offsetLeft = (0, exports.safeBounds)(e).offsetLeft;
    var pos = e.clientX - offsetLeft - barSize / 2;
    var bounded = (0, formatters_1.formatInputValues)(pos, 0, 276);
    return Math.round(bounded / 2.76);
}
exports.getHandleValue = getHandleValue;
function computeSquareXY(hsl) {
    var s = hsl[1] * 100;
    var l = hsl[2] * 100;
    var t = (s * (l < 50 ? l : 100 - l)) / 100;
    var s1 = Math.round((200 * t) / (l + t)) | 0;
    var b1 = Math.round(t + l);
    var x = (squareSize / 100) * s1 - crossSize / 2;
    var y = squareSize - (squareSize / 100) * b1 - crossSize / 2;
    return [x, y];
}
exports.computeSquareXY = computeSquareXY;
function computePickerPosition(e) {
    var _a = (0, exports.safeBounds)(e), offsetLeft = _a.offsetLeft, offsetTop = _a.offsetTop;
    var getX = function () {
        var xPos = e.clientX - offsetLeft - crossSize / 2;
        return (0, formatters_1.formatInputValues)(xPos, -8, 284);
    };
    var getY = function () {
        var yPos = e.clientY - offsetTop - crossSize / 2;
        return (0, formatters_1.formatInputValues)(yPos, -8, 284);
    };
    return [getX(), getY()];
}
exports.computePickerPosition = computePickerPosition;
var getDegrees = function (value) {
    var _a;
    var s1 = value === null || value === void 0 ? void 0 : value.split(',')[0];
    return parseInt((_a = s1 === null || s1 === void 0 ? void 0 : s1.split('(')[1]) === null || _a === void 0 ? void 0 : _a.slice(0, -3));
};
exports.getDegrees = getDegrees;
var getGradientType = function (value) {
    return value === null || value === void 0 ? void 0 : value.split('(')[0];
};
exports.getGradientType = getGradientType;
var getNewHsl = function (newHue, s, l, o, setInternalHue) {
    setInternalHue(newHue);
    var tiny = tc({ h: newHue, s: s, l: l });
    var _a = tiny.toRgb(), r = _a.r, g = _a.g, b = _a.b;
    return "rgba(".concat(r, ", ").concat(g, ", ").concat(b, ", ").concat(o, ")");
};
exports.getNewHsl = getNewHsl;
var safeBounds = function (e) {
    var client = e.target.parentNode.getBoundingClientRect();
    var className = e.target.className;
    var adjuster = className === 'c-resize ps-rl' ? 15 : 0;
    return { offsetLeft: (client === null || client === void 0 ? void 0 : client.x) + adjuster, offsetTop: client === null || client === void 0 ? void 0 : client.y };
};
exports.safeBounds = safeBounds;
var isUpperCase = function (str) {
    var _a;
    return (str === null || str === void 0 ? void 0 : str[0]) === ((_a = str === null || str === void 0 ? void 0 : str[0]) === null || _a === void 0 ? void 0 : _a.toUpperCase());
};
exports.isUpperCase = isUpperCase;
//# sourceMappingURL=utils.js.map